#!/bin/bash

source /backups/patch/settings.sh

cleanup() {
 cd $PATCHBASE
 rm -rf *
 rm -rf /tmp/pinsafe
 echo; echo "Clean up done..."
}

appliance_type() {
 PINSAFE_TYPE=`grep PINSAFE_TYPE $PINSAFE_CONF|cut -d\= -f2`

 if test ! $PINSAFE_TYPE; then
  stnd_err "Appliance type is not correctly configured."; fi
 if test "$PINSAFE_TYPE" = "Single"; then
  PINSAFE_TYPE="Single "; fi
}

check_drbd() {
 DRBD_TYPE=`grep DRBD $PINSAFE_CONF|cut -d\= -f2`
 
 if test "$DRBD_TYPE" = "yes"; then
   SWIVEL=$SWIVEL_DRBD
 fi
}

heading() {
 clear
 echo "${inv} Swivel Maintenance (c) $COPYRIGHT_YEAR${nor}                                             ${inv}$PINSAFE_TYPE${nor}"
 echo
 echo $1
 echo
}

yorn() {
 echo
 echo -n "Are you sure? (Yes/No): "
 read yn
 check_ans $1 $yn
}

check_ans() {
 if test ! $2; then
  $1; fi
 if test ! $2 = "Yes" && test ! $2 = "yes" && test ! $2 = "y" && test ! $2 = "Y" ; then
  $1; fi
}

warning() {
 heading "Upgrading Swivel"
 echo "Continuing will apply patch ${inv}$PATCH_VER${nor}."
 echo "The Swivel solution cannot be used whilst upgrading."
 echo
 yorn exit
}

appliance_version() {
 APPLIANCE_VERS=`grep ^APPLIANCE_VERS= $PINSAFE_CONF|cut -d\= -f2`

 if test $APPLIANCE_VERS && test $APPLIANCE_REQUIRED; then
  if ! version_ge $APPLIANCE_VERS $APPLIANCE_REQUIRED; then
   echo "The appliance requires patching before Swivel can be updated"
   echo; read -p "Press Return to exit" yn
   exit; fi
 else
  echo "Unable to determine appliance version"
  echo; read -p "Press Return to exit" yn
  exit
 fi
}

version_ge() {
  # return 0 iff version1 is greater or equal to version2
  MAJ1=$(echo $1 | cut -d. -f1);
  MIN1=$(echo $1 | cut -d. -f2);
  MIC1=$(echo $1 | cut -d. -f3);

  MAJ2=$(echo $2 | cut -d. -f1);
  MIN2=$(echo $2 | cut -d. -f2);
  MIC2=$(echo $2 | cut -d. -f3);
  if [ $MAJ1 -gt $MAJ2 ]; then return 0; fi
  if [ $MAJ1 -lt $MAJ2 ]; then return 1; fi

  if [ $MIN1 -gt $MIN2 ]; then return 0; fi
  if [ $MIN1 -lt $MIN2 ]; then return 1; fi

  if [ $MIC1 -gt $MIC2 ]; then return 0; fi
  if [ $MIC1 -lt $MIC2 ]; then return 1; fi
  if [ $MIC1 -eq $MIC2 ]; then return 0; fi
  return 1;
}
